@@ -7,7 +7,7 @@ doPkgTests = function(repo, cores = 3L)
      logfun(repo)("NA", paste0("Performing 'extra' commands before installation. ", paste(manifest_df(repo)$name, collapse = " , ")), type = "full")
 
     repo = doExtra(repo)
-    
+
     if(is.null(repo_results(repo)$building))
         repo_results(repo)$building = TRUE
 
@@ -59,28 +59,51 @@ installTest = function(repo, cores = 3L)
     oldlp = .libPaths()
     .libPaths2(loc, exclude.site=TRUE)
     on.exit(.libPaths(oldlp))
-    
-    if(!file.exists(install_result_dir(repo)))
-        dir.create(install_result_dir(repo))
 
-    granpkgs = bres[grepl("^GRAN", bres$name),]
-    bres = bres[!grepl("^GRAN", bres$name),]
+    ## insttmplogs = staging_logs(repo)
+    ## if(!file.exists(insttmplogs))
+    ##     dir.create(insttmplogs, recursive=TRUE)
+
+
+
+    ## we don't install any GRAN packages
+    ##binds is in repo_results row space!!! and it's a logical
+    ## so we need to set elements to false, NOT remove them!
+    rresgraninds = grep("^GRAN", repo_results(repo)$name)
+    binds[rresgraninds ] = FALSE
+    ##bres is in an entirely different space because the packages that failed
+    ## earlier steps (e.g., build fail, or were up to date) are excluded.
+    ## it's a data.frame, so we need to remove the rows we don't want, unlike above
+    bresgraninds = grep("^GRAN", bres$name)
+    bres = bres[-bresgraninds,]
+
+    ## protect ourselves here by asserting dimension conformity was preserved:
+    ## bres should contain 1 row for each TRUE in binds
+    stopifnot(nrow(bres) == sum(binds))
     
+
     res = install.packages2(bres$name, lib = loc,
         repos = reps,
         type = "source", dependencies=TRUE, ## Ncpus = cores, problems with installing deps?
         param = param(repo),
-        outdir = install_result_dir(repo))
+        outdir = staging_logs(repo))
     success = processInstOut(names(res), res, repo)
-    ## why was I removing some of the output logs? Doesn't seem like we want this.
-    ##cleanupInstOut(res)
-    
-    logfun(repo)("NA", paste0("Installation successful for ", sum(success), " of ", length(success), " packages."), type = "full")
+    if(length(success) != nrow(bres) || length(success) != sum(binds))
+        stop("length mismatch between Install test output and packages tested")
+    ## default is the staging_logs dir when repo specified, which is correct here
+    cleanupInstOut(repo= repo) 
 
-    #update the packages in the manifest we tried to build with success/failure
+
+
+    ## if these dimensions don't conform the recycling rule screws us.
+    ## source of long-lived install results misreporting bug.
+    stopifnot(length(binds) == nrow(repo_results(repo)))
+
+    logfun(repo)("NA", paste0("Installation successful for ", sum(success), " of ", length(success), " packages."), type = "full")
+    ##update the packages in the manifest we tried to build with success/failure
     repo_results(repo)$status[binds][!success] = "install failed"
     repo
-    
+
 }
 
 
@@ -107,15 +130,51 @@ processInstOut = function(pkg, out, repo)
     }
     ret
 }
-    
-cleanupInstOut = function(out)
-{
-    torem = out[out!="ok"]
-    file.remove(torem)
 
+## Make sure that old install logs aren't around to gum up the works.
+cleanupInstOut = function(outdir = staging_logs(repo), repo)
+{
+    ## dirs = list.dirs(outdir, recursive=FALSE)
+    ## res = file.rename(dirs, file.path(install_result_dir(repo), basename(dirs)))
+    ## if(!all(res))
+    ##     stop("file renaming appears to have failed")
+    ## invisible(NULL)
+    instlogs = list.files(outdir, pattern = ".*\\.out", full.names=TRUE)
+    res = file.copy(instlogs, install_result_dir(repo), overwrite=TRUE, copy.date=TRUE)
+    if(!all(res))
+        stop("install log copying failed.")
+    file.remove(instlogs)
+    invisible(NULL)
 }
 
 
+
+.innerCheck =  function(nm, tar, repo)
+        {
+            if(grepl("^GRAN", nm)) {
+                logfun(repo)(nm, paste("Not checking", nm, "package to avoid recursion problems"))
+                return(c(paste("*", nm, "not checked to prevent recursion"),
+                         "* DONE",
+                         "* Status: OK"))
+            }
+
+            logfun(repo)(nm, paste("Running R CMD check on ", tar))
+            ## We built the vignettes during this round of building, so if the pkg is going to
+            ##fail on building vignettes it will have already happened by this point
+            cmd = paste0('R_LIBS="', temp_lib(repo),  '" R_HOME="',
+                R.home(),'" R CMD check ', tar, " --no-build-vignettes")
+            env = c(paste0('R_LIBS="', temp_lib(repo), '"'),
+                    paste0('R_HOME="', R.home(), '"'))
+            args = c("check", tar, "--no-build-vignettes")
+            cmd = file.path(R.home("bin"), "Rcmd")
+
+            out = tryCatch(system_w_init(cmd, args = args, env = env,
+                                         intern=TRUE, param = param(repo)),
+                error=function(x) x)
+            out
+
+    }
+
 checkTest = function(repo, cores = 3L)
 {
 ##    if(!check_test_on(repo)) {
@@ -127,13 +186,14 @@ checkTest = function(repo, cores = 3L)
     on.exit(setwd(oldwd))
     logfun(repo)("NA", paste0("Running R CMD check on remaining packages (", sum(getBuilding(repo = repo)), ") using R at ", R.home(), "."), type = "full")
     manifest = manifest_df(repo)
-    binds  = getBuilding(repo = repo)
+    ## binds is indices now, NOT TRUE/FALSE!!!
+    binds  = which(getBuilding(repo = repo))
     bres = getBuildingResults(repo = repo)
     if(!nrow(bres))
         return(repo)
     #pat = paste0("(", paste(bres$name, collapse="|"), ")_.*\\.tar.gz")
     #tars = list.files(pattern = pat)
-    expectedTars = file.path(staging(repo), paste0(bres$name,"_", bres$version, ".tar.gz"))
+    expectedTars = file.path(staging(repo), paste0(bres$name,"_", bres$version, builtPkgExt()))
     tars = expectedTars[file.exists(expectedTars)]
 ##    tars = unlist(mapply(function(nm, vr) list.files(pattern = paste0(nm, "_", vr, ".tar.gz")), nm = bres$name, vr = bres$version))
     if(!identical(expectedTars, tars)){
@@ -143,45 +203,24 @@ checkTest = function(repo, cores = 3L)
         logfun(repo)("NA", c("Tarballs not found for these packages during check test:", paste(bres$name[missing], collapse = " , ")), type = "both")
         repo_results(repo)$status[manifest_df(repo)$name %in% bres$name[missing]] = "Unable to check - missing tarball"
         bres  = bres[!missing,]
-        binds[missing] = FALSE
+        binds = binds[!missing]
     }
     #tars = tars[order(bres$name)]
 ##    ord = mapply(function(nm, vr) grep(paste0(nm, "_", vr), tars), nm = bres$name, vr = bres$version)
-    
-  ##  tars = tars[unlist(ord)]
-    outs = mcmapply2(
-        function(nm, tar, repo)
-        {
-            if(grepl("^GRAN", nm)) {
-                logfun(repo)(nm, paste("Not checking", nm, "package to avoid recursion problems"))
-                return(c(paste("*", nm, "not checked to prevent recursion"),
-                         "* DONE",
-                         "* Status: OK"))
-            }
-            
-            logfun(repo)(nm, paste("Running R CMD check on ", tar))
-            ## We built the vignettes during this round of building, so if the pkg is going to
-            ##fail on building vignettes it will have already happened by this point
-            cmd = paste0('R_LIBS="', temp_lib(repo),  '" R_HOME="',
-                R.home(),'" R CMD check ', tar, " --no-build-vignettes")
-            env = c(paste0('R_LIBS="', temp_lib(repo), '"'),
-                    paste0('R_HOME="', R.home(), '"'))
-            args = c("check", tar, "--no-build-vignettes")
-            cmd = file.path(R.home("bin"), "Rcmd")
-                    
-            out = tryCatch(system_w_init(cmd, args = args, env = env,
-                                         intern=TRUE, param = param(repo)),
-                error=function(x) x)
-            out
 
-    },  nm = bres$name, tar = tars,repo = list(repo), mc.cores = cores,
-        SIMPLIFY=FALSE)
-    
+  ##  tars = tars[unlist(ord)]
+    outs = mcmapply2(function(nm, tar, repo) tryCatch(.innerCheck(nm = nm, tar = tar, repo = repo),
+                                                      error = function(x)x)
+       ,  nm = bres$name, tar = tars,repo = list(repo), mc.cores = cores,
+        SIMPLIFY=FALSE, mc.preschedule=FALSE)
+    if(length(outs) != nrow(bres))
+        stop("Fatal error. I didn't get check output for all checked packages.")
+
     success = mapply(function(nm, out, repo) {
         if(errorOrNonZero(out) || any(grepl("ERROR", out, fixed=TRUE))) {
             logfun(repo)(nm, "R CMD check failed.", type = "both")
             outToErrLog = TRUE
-     
+
             ret = "check fail"
         } else {
             numwarns = length(grep("WARNING", out)) - 1 ##-1 to account for the WARNING count
@@ -211,11 +250,16 @@ checkTest = function(repo, cores = 3L)
         if(outToErrLog)
             logfun(repo)(nm, c("R CMD check output:", out), type="error")
         ret
-        
+
     }, nm = names(outs), out = outs, repo = list(repo))
-  
-    
+
+
     success = unlist(success)
+    if(length(success) != length(binds)) {
+        stop("fatal error. only got ",  length(success), " results from ", length(binds),
+             " check tests.")
+    }
+
 
     logfun(repo)("NA", paste0(sum(isOkStatus(status = success, repo = repo)), " of ", length(success), " packages passed R CMD check"))
     repo_results(repo)$status[binds] = success
